Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to Apache Kafka APIs for Amazon MSK clusters.

Actions, resources, and condition keys for Apache Kafka APIs for Amazon MSK clusters - Service Authorization Reference

# Actions, resources, and condition keys for Apache Kafka APIs for Amazon MSK clusters

Apache Kafka APIs for Amazon MSK clusters (service prefix: `kafka-cluster` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions defined by Apache Kafka APIs for Amazon MSK clusters
- Resource types defined by Apache Kafka APIs for Amazon MSK clusters
- Condition keys for Apache Kafka APIs for Amazon MSK clusters

## Actions defined by Apache Kafka APIs for Amazon MSK clusters

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see The actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
AlterCluster | Grants permission to alter various aspects of the cluster, equivalent to Apache Kafka's ALTER CLUSTER ACL | Write | cluster* |  | kafka-cluster:Connect kafka-cluster:DescribeCluster
AlterClusterDynamicConfiguration | Grants permission to alter the dynamic configuration of a cluster, equivalent to Apache Kafka's ALTER_CONFIGS CLUSTER ACL | Write | cluster* |  | kafka-cluster:Connect kafka-cluster:DescribeClusterDynamicConfiguration
AlterGroup | Grants permission to join groups on a cluster, equivalent to Apache Kafka's READ GROUP ACL | Write | group* |  | kafka-cluster:Connect kafka-cluster:DescribeGroup
AlterTopic | Grants permission to alter topics on a cluster, equivalent to Apache Kafka's ALTER TOPIC ACL | Write | topic* |  | kafka-cluster:Connect kafka-cluster:DescribeTopic
AlterTopicDynamicConfiguration | Grants permission to alter the dynamic configuration of topics on a cluster, equivalent to Apache Kafka's ALTER_CONFIGS TOPIC ACL | Write | topic* |  | kafka-cluster:Connect kafka-cluster:DescribeTopicDynamicConfiguration
AlterTransactionalId | Grants permission to alter transactional IDs on a cluster, equivalent to Apache Kafka's WRITE TRANSACTIONAL_ID ACL | Write | transactional-id* |  | kafka-cluster:Connect kafka-cluster:DescribeTransactionalId kafka-cluster:WriteData
Connect | Grants permission to connect and authenticate to the cluster | Write | cluster* |  |
CreateTopic | Grants permission to create topics on a cluster, equivalent to Apache Kafka's CREATE CLUSTER/TOPIC ACL | Write | topic* |  | kafka-cluster:Connect
DeleteGroup | Grants permission to delete groups on a cluster, equivalent to Apache Kafka's DELETE GROUP ACL | Write | group* |  | kafka-cluster:Connect kafka-cluster:DescribeGroup
DeleteTopic | Grants permission to delete topics on a cluster, equivalent to Apache Kafka's DELETE TOPIC ACL | Write | topic* |  | kafka-cluster:Connect kafka-cluster:DescribeTopic
DescribeCluster | Grants permission to describe various aspects of the cluster, equivalent to Apache Kafka's DESCRIBE CLUSTER ACL | List | cluster* |  | kafka-cluster:Connect
DescribeClusterDynamicConfiguration | Grants permission to describe the dynamic configuration of a cluster, equivalent to Apache Kafka's DESCRIBE_CONFIGS CLUSTER ACL | List | cluster* |  | kafka-cluster:Connect
DescribeGroup | Grants permission to describe groups on a cluster, equivalent to Apache Kafka's DESCRIBE GROUP ACL | List | group* |  | kafka-cluster:Connect
DescribeTopic | Grants permission to describe topics on a cluster, equivalent to Apache Kafka's DESCRIBE TOPIC ACL | List | topic* |  | kafka-cluster:Connect
DescribeTopicDynamicConfiguration | Grants permission to describe the dynamic configuration of topics on a cluster, equivalent to Apache Kafka's DESCRIBE_CONFIGS TOPIC ACL | List | topic* |  | kafka-cluster:Connect
DescribeTransactionalId | Grants permission to describe transactional IDs on a cluster, equivalent to Apache Kafka's DESCRIBE TRANSACTIONAL_ID ACL | List | transactional-id* |  | kafka-cluster:Connect
ReadData | Grants permission to read data from topics on a cluster, equivalent to Apache Kafka's READ TOPIC ACL | Read | topic* |  | kafka-cluster:AlterGroup kafka-cluster:Connect kafka-cluster:DescribeTopic
WriteData | Grants permission to write data to topics on a cluster, equivalent to Apache Kafka's WRITE TOPIC ACL | Write | topic* |  | kafka-cluster:Connect kafka-cluster:DescribeTopic
WriteDataIdempotently | Grants permission to write data idempotently on a cluster, equivalent to Apache Kafka's IDEMPOTENT_WRITE CLUSTER ACL | Write | cluster* |  | kafka-cluster:Connect kafka-cluster:WriteData

## Resource types defined by Apache Kafka APIs for Amazon MSK clusters

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see The resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
cluster | `arn:$ { Partition}:kafka:$ { Region}:$ { Account}:cluster/$ { ClusterName}/$ { ClusterUuid}` | aws:ResourceTag/${TagKey}
topic | `arn:$ { Partition}:kafka:$ { Region}:$ { Account}:topic/$ { ClusterName}/$ { ClusterUuid}/$ { TopicName}` |
group | `arn:$ { Partition}:kafka:$ { Region}:$ { Account}:group/$ { ClusterName}/$ { ClusterUuid}/$ { GroupName}` |
transactional-id | `arn:$ { Partition}:kafka:$ { Region}:$ { Account}:transactional-id/$ { ClusterName}/$ { ClusterUuid}/$ { TransactionalId}` |

## Condition keys for Apache Kafka APIs for Amazon MSK clusters

Apache Kafka APIs for Amazon MSK clusters defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see The condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:ResourceTag/${TagKey} | Filters actions based on tag key-value pairs attached to the resource. The resource tag context key will only apply to the cluster resource, not topics, groups and transactional IDs | String

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.